summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorsooyeon.kim <sooyeon.kim@samsung.com>2017-07-10 18:49:05 +0900
committersooyeon.kim <sooyeon.kim@samsung.com>2017-07-12 16:27:24 +0900
commit1fc27db6321191b51bff14005ffb58d5fe5f4725 (patch)
treec037dd09468a1f7a19af7ffe33380541bf27d6c2
parent991a883c76b51e12910ab4e12225489e61ab1935 (diff)
downloaduix-tts-tizen_4.0.tar.gz
uix-tts-tizen_4.0.tar.bz2
uix-tts-tizen_4.0.zip
Change-Id: Ia4b3a5724eed8b35d6d2c4de2642575cf7d53f27 Signed-off-by: sooyeon.kim <sooyeon.kim@samsung.com>
-rw-r--r--Tizen.Uix.Tts/Tizen.Uix.Tts.csproj2
-rwxr-xr-xTizen.Uix.Tts/Tizen.Uix.Tts/ErrorOccurredEventArgs.cs (renamed from Tizen.Uix.Tts/Tizen.Uix.Tts/ErrorOccuredEventArgs.cs)6
-rwxr-xr-xTizen.Uix.Tts/Tizen.Uix.Tts/ExceptionFactory.cs2
-rwxr-xr-xTizen.Uix.Tts/Tizen.Uix.Tts/TtsClient.cs36
4 files changed, 23 insertions, 23 deletions
diff --git a/Tizen.Uix.Tts/Tizen.Uix.Tts.csproj b/Tizen.Uix.Tts/Tizen.Uix.Tts.csproj
index 9d29a93..f14d331 100644
--- a/Tizen.Uix.Tts/Tizen.Uix.Tts.csproj
+++ b/Tizen.Uix.Tts/Tizen.Uix.Tts.csproj
@@ -1,7 +1,7 @@
<Project Sdk="Microsoft.NET.Sdk">
<PropertyGroup>
- <Version>1.0.2</Version>
+ <Version>1.0.3</Version>
<Authors>Samsung Electronics</Authors>
<Copyright>© Samsung Electronics Co., Ltd All Rights Reserved</Copyright>
<Description>TTS Uix API for Tizen .NET</Description>
diff --git a/Tizen.Uix.Tts/Tizen.Uix.Tts/ExceptionFactory.cs b/Tizen.Uix.Tts/Tizen.Uix.Tts/ExceptionFactory.cs
index a29d9dd..a471f7d 100755
--- a/Tizen.Uix.Tts/Tizen.Uix.Tts/ExceptionFactory.cs
+++ b/Tizen.Uix.Tts/Tizen.Uix.Tts/ExceptionFactory.cs
@@ -36,7 +36,7 @@ namespace Tizen.Uix.Tts
case TtsError.IoError:
{
- exp = new InvalidOperationException("I/O Error Occured");
+ exp = new InvalidOperationException("I/O Error Occurred");
break;
}
diff --git a/Tizen.Uix.Tts/Tizen.Uix.Tts/ErrorOccuredEventArgs.cs b/Tizen.Uix.Tts/Tizen.Uix.Tts/ErrorOccurredEventArgs.cs
index dd173dc..09bcb67 100755
--- a/Tizen.Uix.Tts/Tizen.Uix.Tts/ErrorOccuredEventArgs.cs
+++ b/Tizen.Uix.Tts/Tizen.Uix.Tts/ErrorOccurredEventArgs.cs
@@ -21,14 +21,14 @@ using static Interop.Tts;
namespace Tizen.Uix.Tts
{
/// <summary>
/// This class holds information related to the TTS ErrorOccured Event
/// </summary>
/// <since_tizen> 3 </since_tizen>
- public class ErrorOccuredEventArgs
+ public class ErrorOccurredEventArgs
{
private IntPtr _handle;
- internal ErrorOccuredEventArgs(IntPtr handle, int utteranceId, Interop.Tts.TtsError error)
+ internal ErrorOccurredEventArgs(IntPtr handle, int utteranceId, Interop.Tts.TtsError error)
{
this._handle = handle;
this.UtteranceId = utteranceId;
@@ -21,14 +21,14 @@ using static Interop.Tts;
{
/// <summary>
- /// This class holds information related to the TTS ErrorOccured Event
+ /// This class holds information related to the TTS ErrorOccurred Event
/// </summary>
/// <since_tizen> 3 </since_tizen>
diff --git a/Tizen.Uix.Tts/Tizen.Uix.Tts/TtsClient.cs b/Tizen.Uix.Tts/Tizen.Uix.Tts/TtsClient.cs
index a8dedcc..87cfb12 100755
--- a/Tizen.Uix.Tts/Tizen.Uix.Tts/TtsClient.cs
+++ b/Tizen.Uix.Tts/Tizen.Uix.Tts/TtsClient.cs
@@ -199,7 +199,7 @@ namespace Tizen.Uix.Tts
private event EventHandler<StateChangedEventArgs> _stateChanged;
private event EventHandler<UtteranceEventArgs> _utteranceStarted;
private event EventHandler<UtteranceEventArgs> _utteranceCompleted;
- private event EventHandler<ErrorOccuredEventArgs> _errorOccured;
+ private event EventHandler<ErrorOccurredEventArgs> _errorOccurred;
private event EventHandler<DefaultVoiceChangedEventArgs> _defaultVoiceChanged;
private event EventHandler<EngineChangedEventArgs> _engineChanged;
private bool disposedValue = false;
@@ -220,7 +220,7 @@ namespace Tizen.Uix.Tts
/// http://tizen.org/feature/speech.synthesis
/// </feature>
/// <exception cref="InvalidOperationException">
- /// This Exception can be due to the following reaons
+ /// This Exception can be due to the following reasons
/// 1. Operation Failed
/// 2. Engine Not Found
/// </exception>
@@ -371,7 +371,7 @@ namespace Tizen.Uix.Tts
/// Event to be invoked when an error occurs.
/// </summary>
/// <since_tizen> 3 </since_tizen>
- public event EventHandler<ErrorOccuredEventArgs> ErrorOccured
+ public event EventHandler<ErrorOccurredEventArgs> ErrorOccurred
{
add
{
@@ -379,18 +379,18 @@ namespace Tizen.Uix.Tts
{
_errorDelegate = (IntPtr handle, int uttId, TtsError reason, IntPtr userData) =>
{
- ErrorOccuredEventArgs args = new ErrorOccuredEventArgs(handle, uttId, reason);
- _errorOccured?.Invoke(this, args);
+ ErrorOccurredEventArgs args = new ErrorOccurredEventArgs(handle, uttId, reason);
+ _errorOccurred?.Invoke(this, args);
};
TtsError error = TtsSetErrorCB(_handle, _errorDelegate, IntPtr.Zero);
if (error != TtsError.None)
{
- Log.Error(LogTag, "Add ErrorOccured Failed with error " + error);
+ Log.Error(LogTag, "Add ErrorOccurred Failed with error " + error);
}
else
{
- _errorOccured += value;
+ _errorOccurred += value;
}
}
}
@@ -402,10 +402,10 @@ namespace Tizen.Uix.Tts
TtsError error = TtsUnsetErrorCB(_handle);
if (error != TtsError.None)
{
- Log.Error(LogTag, "Remove ErrorOccured Failed with error " + error);
+ Log.Error(LogTag, "Remove ErrorOccurred Failed with error " + error);
}
- _errorOccured -= value;
+ _errorOccurred -= value;
}
}
}
@@ -606,7 +606,7 @@ namespace Tizen.Uix.Tts
/// The Mode value
/// </returns>
/// <exception cref="InvalidOperationException">
- /// This Exception can be due to the following reaons while setting the value
+ /// This Exception can be due to the following reasons while setting the value
/// 1. Operation Failed
/// 2. Engine Not Found
/// </exception>
@@ -691,7 +691,7 @@ namespace Tizen.Uix.Tts
/// </pre>
/// <post>
/// If this function is successful, the TTS state will be Ready
/// If this function is unsuccessful, ErrorOccured event will be invoked
/// </post>
public void Prepare()
{
@@ -788,7 +788,7 @@ namespace Tizen.Uix.Tts
/// http://tizen.org/feature/speech.synthesis
/// </feature>
/// <exception cref="InvalidOperationException">
- /// This Exception can be due to the following reaons
+ /// This Exception can be due to the following reasons
/// 1. Invalid State
/// 2. Engine Not found
/// 3. Operation Failure
@@ -828,7 +828,7 @@ namespace Tizen.Uix.Tts
/// http://tizen.org/feature/speech.synthesis
/// </feature>
/// <exception cref="InvalidOperationException">
- /// This Exception can be due to the following reaons
+ /// This Exception can be due to the following reasons
/// 1. Invalid State
/// 2. Engine Not found
/// 3. Operation Failure
@@ -862,7 +862,7 @@ namespace Tizen.Uix.Tts
/// http://tizen.org/feature/speech.synthesis
/// </feature>
/// <exception cref="InvalidOperationException">
- /// This Exception can be due to the following reaons
+ /// This Exception can be due to the following reasons
/// 1. Invalid State
/// 2. Operation Failure
/// </exception>
@@ -913,7 +913,7 @@ namespace Tizen.Uix.Tts
/// http://tizen.org/feature/speech.synthesis
/// </feature>
/// <exception cref="InvalidOperationException">
- /// This Exception can be due to the following reaons
+ /// This Exception can be due to the following reasons
/// 1. Invalid State
/// 2. Operation Failure
/// 3. Invalid Voice
@@ -949,7 +949,7 @@ namespace Tizen.Uix.Tts
/// http://tizen.org/feature/speech.synthesis
/// </feature>
/// <exception cref="InvalidOperationException">
- /// This Exception can be due to the following reaons
+ /// This Exception can be due to the following reasons
/// 1. Invalid State
/// 2. Operation Failure
/// 3. Out of Network
@@ -983,7 +983,7 @@ namespace Tizen.Uix.Tts
/// http://tizen.org/feature/speech.synthesis
/// </feature>
/// <exception cref="InvalidOperationException">
- /// This Exception can be due to the following reaons
+ /// This Exception can be due to the following reasons
/// 1. Invalid State
/// 2. Operation Failure
/// </exception>
@@ -1016,7 +1016,7 @@ namespace Tizen.Uix.Tts
/// http://tizen.org/feature/speech.synthesis
/// </feature>
/// <exception cref="InvalidOperationException">
- /// This Exception can be due to the following reaons
+ /// This Exception can be due to the following reasons
/// 1. Invalid State
/// 2. Operation Failure
/// </exception>
@@ -691,7 +691,7 @@ namespace Tizen.Uix.Tts
/// <post>
/// If this function is successful, the TTS state will be Ready
- /// If this function is unsuccessful, ErrorOccured event will be invoked
+ /// If this function is unsuccessful, ErrorOccurred event will be invoked
/// </post>
public void Prepare()